quantizationtools.QGridTempoLookup
==================================

.. inheritance-diagram:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup
   :private-bases:

.. autoclass:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.beatspan

.. autoattribute:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.tempo

Methods
-------

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.clear

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.copy

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.get

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.has_key

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.items

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.iteritems

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.iterkeys

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.itervalues

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.keys

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.pop

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.popitem

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.setdefault

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.update

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.values

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.viewitems

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.viewkeys

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.viewvalues

   .. note:: Inherited from `__builtin__.dict`

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__cmp__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__contains__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__delitem__

   .. note:: Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__eq__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__ge__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__getitem__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__gt__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__iter__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__le__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__len__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__lt__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__ne__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__repr__

   .. note:: Inherited from `__builtin__.dict`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__setitem__

   .. note:: Inherited from :py:class:`datastructuretools.ImmutableDictionary <abjad.tools.datastructuretools.ImmutableDictionary.ImmutableDictionary.ImmutableDictionary>`

.. automethod:: abjad.tools.quantizationtools.QGridTempoLookup.QGridTempoLookup.QGridTempoLookup.__str__

   .. note:: Inherited from `__builtin__.object`
